Class: Google::Cloud::AgentRegistry::V1::Agent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agent.rb

Overview

Represents an Agent. "A2A" below refers to the Agent-to-Agent protocol.

Defined Under Namespace

Classes: AttributesEntry, Card, Protocol, Skill

Instance Attribute Summary collapse

Instance Attribute Details

#agent_id::String (readonly)

Returns Output only. A stable, globally unique identifier for agents.

Returns:

  • (::String)

    Output only. A stable, globally unique identifier for agents.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#attributes::Google::Protobuf::Map{::String => ::Google::Protobuf::Struct} (readonly)

Returns Output only. Attributes of the Agent. Valid values:

  • agentregistry.googleapis.com/system/Framework: "google-adk" - the agent framework used to develop the Agent. Example values: "google-adk", "langchain", "custom".
  • agentregistry.googleapis.com/system/RuntimeIdentity: "principal://..." - the runtime identity associated with the Agent.
  • agentregistry.googleapis.com/system/RuntimeReference: {"uri": "//..."}
  • the URI of the underlying resource hosting the Agent, for example, the Reasoning Engine URI.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Protobuf::Struct})

    Output only. Attributes of the Agent. Valid values:

    • agentregistry.googleapis.com/system/Framework: "google-adk" - the agent framework used to develop the Agent. Example values: "google-adk", "langchain", "custom".
    • agentregistry.googleapis.com/system/RuntimeIdentity: "principal://..." - the runtime identity associated with the Agent.
    • agentregistry.googleapis.com/system/RuntimeReference: {"uri": "//..."}
    • the URI of the underlying resource hosting the Agent, for example, the Reasoning Engine URI.


81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#card::Google::Cloud::AgentRegistry::V1::Agent::Card (readonly)

Returns Output only. Full Agent Card payload, when available.

Returns:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create time.

Returns:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String (readonly)

Returns Output only. The description of the Agent, often obtained from the A2A Agent Card. Empty if Agent Card has no description.

Returns:

  • (::String)

    Output only. The description of the Agent, often obtained from the A2A Agent Card. Empty if Agent Card has no description.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String (readonly)

Returns Output only. The display name of the agent, often obtained from the A2A Agent Card.

Returns:

  • (::String)

    Output only. The display name of the agent, often obtained from the A2A Agent Card.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location::String (readonly)

Returns Output only. The location where agent is hosted. The value is defined by the hosting environment (i.e. cloud provider).

Returns:

  • (::String)

    Output only. The location where agent is hosted. The value is defined by the hosting environment (i.e. cloud provider).



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The resource name of an Agent. Format: projects/{project}/locations/{location}/agents/{agent}.

Returns:

  • (::String)

    Identifier. The resource name of an Agent. Format: projects/{project}/locations/{location}/agents/{agent}.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#protocols::Array<::Google::Cloud::AgentRegistry::V1::Agent::Protocol> (readonly)

Returns Output only. The connection details for the Agent.

Returns:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#skills::Array<::Google::Cloud::AgentRegistry::V1::Agent::Skill> (readonly)

Returns Output only. Skills the agent possesses, often obtained from the A2A Agent Card.

Returns:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. A universally unique identifier for the Agent.

Returns:

  • (::String)

    Output only. A universally unique identifier for the Agent.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update time.

Returns:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#version::String (readonly)

Returns Output only. The version of the Agent, often obtained from the A2A Agent Card. Empty if Agent Card has no version or agent is not an A2A Agent.

Returns:

  • (::String)

    Output only. The version of the Agent, often obtained from the A2A Agent Card. Empty if Agent Card has no version or agent is not an A2A Agent.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 81

class Agent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the protocol of an Agent.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type]
  #     Output only. The type of the protocol.
  # @!attribute [r] protocol_version
  #   @return [::String]
  #     Output only. The version of the protocol, for example, the A2A Agent Card
  #     version.
  # @!attribute [r] interfaces
  #   @return [::Array<::Google::Cloud::AgentRegistry::V1::Interface>]
  #     Output only. The connection details for the Agent.
  class Protocol
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the protocol.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # The interfaces point to an A2A Agent following the A2A
      # specification.
      A2A_AGENT = 1

      # Agent does not follow any standard protocol.
      CUSTOM = 2
    end
  end

  # Represents the skills of an Agent.
  # @!attribute [r] id
  #   @return [::String]
  #     Output only. A unique identifier for the agent's skill.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. A human-readable name for the agent's skill.
  # @!attribute [r] description
  #   @return [::String]
  #     Output only. A more detailed description of the skill.
  # @!attribute [r] tags
  #   @return [::Array<::String>]
  #     Output only. Keywords describing the skill.
  # @!attribute [r] examples
  #   @return [::Array<::String>]
  #     Output only. Example prompts or scenarios this skill can handle.
  class Skill
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Full Agent Card payload, often obtained from the A2A Agent Card.
  # @!attribute [r] type
  #   @return [::Google::Cloud::AgentRegistry::V1::Agent::Card::Type]
  #     Output only. The type of agent card.
  # @!attribute [r] content
  #   @return [::Google::Protobuf::Struct]
  #     Output only. The content of the agent card.
  class Card
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Represents the type of the agent card.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Indicates that the card is an A2A Agent Card.
      A2A_AGENT_CARD = 1
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end