Class: Google::Cloud::AgentRegistry::V1::Agent::Protocol

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agent.rb

Overview

Represents the protocol of an Agent.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#interfaces::Array<::Google::Cloud::AgentRegistry::V1::Interface> (readonly)

Returns Output only. The connection details for the Agent.

Returns:



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 96

class Protocol
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the protocol.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # The interfaces point to an A2A Agent following the A2A
    # specification.
    A2A_AGENT = 1

    # Agent does not follow any standard protocol.
    CUSTOM = 2
  end
end

#protocol_version::String (readonly)

Returns Output only. The version of the protocol, for example, the A2A Agent Card version.

Returns:

  • (::String)

    Output only. The version of the protocol, for example, the A2A Agent Card version.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 96

class Protocol
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the protocol.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # The interfaces point to an A2A Agent following the A2A
    # specification.
    A2A_AGENT = 1

    # Agent does not follow any standard protocol.
    CUSTOM = 2
  end
end

#type::Google::Cloud::AgentRegistry::V1::Agent::Protocol::Type (readonly)

Returns Output only. The type of the protocol.

Returns:



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'proto_docs/google/cloud/agentregistry/v1/agent.rb', line 96

class Protocol
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the protocol.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # The interfaces point to an A2A Agent following the A2A
    # specification.
    A2A_AGENT = 1

    # Agent does not follow any standard protocol.
    CUSTOM = 2
  end
end