Class: Google::Cloud::AgentRegistry::V1::Binding

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/binding.rb

Overview

Represents a user-defined Binding.

Defined Under Namespace

Classes: AuthProviderBinding, Source, Target

Instance Attribute Summary collapse

Instance Attribute Details

#auth_provider_binding::Google::Cloud::AgentRegistry::V1::Binding::AuthProviderBinding

Returns The binding for AuthProvider.

Returns:



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when this binding was created.

Returns:



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns Optional. User-defined description of a Binding. Can have a maximum length of 2048 characters.

Returns:

  • (::String)

    Optional. User-defined description of a Binding. Can have a maximum length of 2048 characters.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. User-defined display name for the Binding. Can have a maximum length of 63 characters.

Returns:

  • (::String)

    Optional. User-defined display name for the Binding. Can have a maximum length of 63 characters.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Required. Identifier. The resource name of the Binding. Format: projects/{project}/locations/{location}/bindings/{binding}.

Returns:

  • (::String)

    Required. Identifier. The resource name of the Binding. Format: projects/{project}/locations/{location}/bindings/{binding}.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source::Google::Cloud::AgentRegistry::V1::Binding::Source

Returns Required. The target Agent of the Binding.

Returns:



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#target::Google::Cloud::AgentRegistry::V1::Binding::Target

Returns Required. The target Agent Registry Resource of the Binding.

Returns:



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when this binding was last updated.

Returns:



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 52

class Binding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The source of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the source Agent.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  class Source
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The target of the Binding.
  # @!attribute [rw] identifier
  #   @return [::String]
  #     The identifier of the target Agent, MCP Server, or Endpoint.
  #     Format:
  #
  #     * `urn:agent:{publisher}:{namespace}:{name}`
  #     * `urn:mcp:{publisher}:{namespace}:{name}`
  #     * `urn:endpoint:{publisher}:{namespace}:{name}`
  class Target
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The AuthProvider of the Binding.
  # @!attribute [rw] auth_provider
  #   @return [::String]
  #     Required. The resource name of the target AuthProvider.
  #     Format:
  #
  #     * `projects/{project}/locations/{location}/authProviders/{auth_provider}`
  # @!attribute [rw] scopes
  #   @return [::Array<::String>]
  #     Optional. The list of OAuth2 scopes of the AuthProvider.
  # @!attribute [rw] continue_uri
  #   @return [::String]
  #     Optional. The continue URI of the AuthProvider.
  #     The URI is used to reauthenticate the user and finalize the managed OAuth
  #     flow.
  class AuthProviderBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end