Class: Google::Cloud::AgentRegistry::V1::Binding::AuthProviderBinding

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/binding.rb

Overview

The AuthProvider of the Binding.

Instance Attribute Summary collapse

Instance Attribute Details

#auth_provider::String

Returns Required. The resource name of the target AuthProvider. Format:

  • projects/{project}/locations/{location}/authProviders/{auth_provider}.

Returns:

  • (::String)

    Required. The resource name of the target AuthProvider. Format:

    • projects/{project}/locations/{location}/authProviders/{auth_provider}


97
98
99
100
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 97

class AuthProviderBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#continue_uri::String

Returns Optional. The continue URI of the AuthProvider. The URI is used to reauthenticate the user and finalize the managed OAuth flow.

Returns:

  • (::String)

    Optional. The continue URI of the AuthProvider. The URI is used to reauthenticate the user and finalize the managed OAuth flow.



97
98
99
100
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 97

class AuthProviderBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scopes::Array<::String>

Returns Optional. The list of OAuth2 scopes of the AuthProvider.

Returns:

  • (::Array<::String>)

    Optional. The list of OAuth2 scopes of the AuthProvider.



97
98
99
100
# File 'proto_docs/google/cloud/agentregistry/v1/binding.rb', line 97

class AuthProviderBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end