Class: Google::Cloud::AgentRegistry::V1::CreateServiceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::CreateServiceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for creating a Service
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
-
#service ⇒ ::Google::Cloud::AgentRegistry::V1::Service
Required.
-
#service_id ⇒ ::String
Required.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The project and location to create the Service in.
Expected format: projects/{project}/locations/{location}.
406 407 408 409 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 406 class CreateServiceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
406 407 408 409 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 406 class CreateServiceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service ⇒ ::Google::Cloud::AgentRegistry::V1::Service
Returns Required. The Service resource that is being created.
Format: projects/{project}/locations/{location}/services/{service}.
406 407 408 409 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 406 class CreateServiceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_id ⇒ ::String
Returns Required. The ID to use for the service, which will become the final component of the service's resource name.
This value should be 4-63 characters, and valid characters
are /[a-z][0-9]-/.
406 407 408 409 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 406 class CreateServiceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |