Class: Google::Cloud::AgentRegistry::V1::Endpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/endpoint.rb

Overview

Represents an Endpoint.

Defined Under Namespace

Classes: AttributesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Protobuf::Map{::String => ::Google::Protobuf::Struct} (readonly)

Returns Output only. Attributes of the Endpoint.

Valid values:

  • agentregistry.googleapis.com/system/RuntimeReference: {"uri": "//..."} - the URI of the underlying resource hosting the Endpoint, for example, the GKE Deployment.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Protobuf::Struct})

    Output only. Attributes of the Endpoint.

    Valid values:

    • agentregistry.googleapis.com/system/RuntimeReference: {"uri": "//..."} - the URI of the underlying resource hosting the Endpoint, for example, the GKE Deployment.


56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create time.

Returns:



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String (readonly)

Returns Output only. Description of an Endpoint.

Returns:

  • (::String)

    Output only. Description of an Endpoint.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String (readonly)

Returns Output only. Display name for the Endpoint.

Returns:

  • (::String)

    Output only. Display name for the Endpoint.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#endpoint_id::String (readonly)

Returns Output only. A stable, globally unique identifier for Endpoint.

Returns:

  • (::String)

    Output only. A stable, globally unique identifier for Endpoint.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#interfaces::Array<::Google::Cloud::AgentRegistry::V1::Interface>

Returns Required. The connection details for the Endpoint.

Returns:



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The resource name of the Endpoint. Format: projects/{project}/locations/{location}/endpoints/{endpoint}.

Returns:

  • (::String)

    Identifier. The resource name of the Endpoint. Format: projects/{project}/locations/{location}/endpoints/{endpoint}.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update time.

Returns:



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'proto_docs/google/cloud/agentregistry/v1/endpoint.rb', line 56

class Endpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Protobuf::Struct]
  class AttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end