Class: Google::Cloud::AgentRegistry::V1::FetchAvailableBindingsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb

Overview

Message for fetching available Bindings.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. Page size is 500 if unspecified and is capped at 500 even if a larger value is given.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. Page size is 500 if unspecified and is capped at 500 even if a larger value is given.



438
439
440
441
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 438

class FetchAvailableBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



438
439
440
441
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 438

class FetchAvailableBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, in the format projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent, in the format projects/{project}/locations/{location}.



438
439
440
441
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 438

class FetchAvailableBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_identifier::String

Returns The identifier of the source Agent. Format:

  • urn:agent:{publisher}:{namespace}:{name}.

Returns:

  • (::String)

    The identifier of the source Agent. Format:

    • urn:agent:{publisher}:{namespace}:{name}


438
439
440
441
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 438

class FetchAvailableBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_identifier::String

Returns Optional. The identifier of the target Agent, MCP Server, or Endpoint. Format:

  • urn:agent:{publisher}:{namespace}:{name}
  • urn:mcp:{publisher}:{namespace}:{name}
  • urn:endpoint:{publisher}:{namespace}:{name}.

Returns:

  • (::String)

    Optional. The identifier of the target Agent, MCP Server, or Endpoint. Format:

    • urn:agent:{publisher}:{namespace}:{name}
    • urn:mcp:{publisher}:{namespace}:{name}
    • urn:endpoint:{publisher}:{namespace}:{name}


438
439
440
441
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 438

class FetchAvailableBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end