Class: Google::Cloud::AgentRegistry::V1::FetchAvailableBindingsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::FetchAvailableBindingsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for response to fetching available Bindings.
Instance Attribute Summary collapse
-
#bindings ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Binding>
The list of Bindings.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
Instance Attribute Details
#bindings ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Binding>
Returns The list of Bindings.
450 451 452 453 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 450 class FetchAvailableBindingsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
450 451 452 453 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 450 class FetchAvailableBindingsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |