Class: Google::Cloud::AgentRegistry::V1::ListBindingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb

Overview

Message for response to listing Bindings

Instance Attribute Summary collapse

Instance Attribute Details

#bindings::Array<::Google::Cloud::AgentRegistry::V1::Binding>

Returns The list of Binding resources matching the parent and filter criteria in the request. Each Binding resource follows the format: projects/{project}/locations/{location}/bindings/{binding}.

Returns:

  • (::Array<::Google::Cloud::AgentRegistry::V1::Binding>)

    The list of Binding resources matching the parent and filter criteria in the request. Each Binding resource follows the format: projects/{project}/locations/{location}/bindings/{binding}.



581
582
583
584
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 581

class ListBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token identifying a page of results the server should return. Used in [page_token][google.cloud.agentregistry.v1main.ListBindingsRequest.page_token].

Returns:

  • (::String)

    A token identifying a page of results the server should return. Used in [page_token][google.cloud.agentregistry.v1main.ListBindingsRequest.page_token].



581
582
583
584
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 581

class ListBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end