Class: Google::Cloud::AgentRegistry::V1::ListMcpServersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb

Overview

Message for requesting list of McpServers

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filtering results.

Returns:

  • (::String)

    Optional. Filtering results



219
220
221
222
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 219

class ListMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Hint for how to order the results.

Returns:

  • (::String)

    Optional. Hint for how to order the results



219
220
221
222
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 219

class ListMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



219
220
221
222
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 219

class ListMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



219
220
221
222
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 219

class ListMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for ListMcpServersRequest. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. Parent value for ListMcpServersRequest. Format: projects/{project}/locations/{location}.



219
220
221
222
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 219

class ListMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end