Class: Google::Cloud::AgentRegistry::V1::ListMcpServersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::ListMcpServersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for response to listing McpServers
Instance Attribute Summary collapse
-
#mcp_servers ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::McpServer>
The list of McpServers.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
Instance Attribute Details
#mcp_servers ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::McpServer>
Returns The list of McpServers.
231 232 233 234 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 231 class ListMcpServersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
231 232 233 234 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 231 class ListMcpServersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |