Class: Google::Cloud::AgentRegistry::V1::ListServicesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::ListServicesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for requesting list of Services
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A query string used to filter the list of services returned. The filter expression must follow AIP-160 syntax.
Filtering is supported on the name, display_name, description,
and labels fields.
Some examples:
name = "projects/p1/locations/l1/services/s1"display_name = "my-service"description : "myservice description"labels.env = "prod".
344 345 346 347 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 344 class ListServicesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
344 345 346 347 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 344 class ListServicesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
344 345 346 347 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 344 class ListServicesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location to list services in.
Expected format: projects/{project}/locations/{location}.
344 345 346 347 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 344 class ListServicesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |