Class: Google::Cloud::AgentRegistry::V1::ListServicesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::ListServicesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for response to listing Services
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#services ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Service>
The list of Service resources matching the parent and filter criteria in the request.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return. Used in [page_token][google.cloud.agentregistry.v1main.ListServicesRequest.page_token].
360 361 362 363 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 360 class ListServicesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#services ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Service>
Returns The list of Service resources matching the parent and filter criteria in
the request. Each Service resource follows the format:
projects/{project}/locations/{location}/services/{service}.
360 361 362 363 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 360 class ListServicesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |