Class: Google::Cloud::AgentRegistry::V1::McpServer::Tool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/mcp_server.rb

Overview

Represents a single tool provided by an MCP Server.

Defined Under Namespace

Classes: Annotations

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Cloud::AgentRegistry::V1::McpServer::Tool::Annotations (readonly)

Returns Output only. Annotations associated with the tool.

Returns:



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 74

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Annotations describing the characteristics and behavior of a tool or
  # operation.
  # @!attribute [r] title
  #   @return [::String]
  #     Output only. A human-readable title for the tool.
  # @!attribute [r] destructive_hint
  #   @return [::Boolean]
  #     Output only. If true, the tool may perform destructive updates to its
  #     environment. If false, the tool performs only additive updates. NOTE:
  #     This property is meaningful only when `read_only_hint == false`
  #     Default: true
  # @!attribute [r] idempotent_hint
  #   @return [::Boolean]
  #     Output only. If true, calling the tool repeatedly with the same
  #     arguments will have no additional effect on its environment. NOTE: This
  #     property is meaningful only when `read_only_hint == false` Default:
  #     false
  # @!attribute [r] open_world_hint
  #   @return [::Boolean]
  #     Output only. If true, this tool may interact with an "open world" of
  #     external entities. If false, the tool's domain of interaction is
  #     closed. For example, the world of a web search tool is open, whereas
  #     that of a memory tool is not. Default: true
  # @!attribute [r] read_only_hint
  #   @return [::Boolean]
  #     Output only. If true, the tool does not modify its environment.
  #     Default: false
  class Annotations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String (readonly)

Returns Output only. Description of what the tool does.

Returns:

  • (::String)

    Output only. Description of what the tool does.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 74

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Annotations describing the characteristics and behavior of a tool or
  # operation.
  # @!attribute [r] title
  #   @return [::String]
  #     Output only. A human-readable title for the tool.
  # @!attribute [r] destructive_hint
  #   @return [::Boolean]
  #     Output only. If true, the tool may perform destructive updates to its
  #     environment. If false, the tool performs only additive updates. NOTE:
  #     This property is meaningful only when `read_only_hint == false`
  #     Default: true
  # @!attribute [r] idempotent_hint
  #   @return [::Boolean]
  #     Output only. If true, calling the tool repeatedly with the same
  #     arguments will have no additional effect on its environment. NOTE: This
  #     property is meaningful only when `read_only_hint == false` Default:
  #     false
  # @!attribute [r] open_world_hint
  #   @return [::Boolean]
  #     Output only. If true, this tool may interact with an "open world" of
  #     external entities. If false, the tool's domain of interaction is
  #     closed. For example, the world of a web search tool is open, whereas
  #     that of a memory tool is not. Default: true
  # @!attribute [r] read_only_hint
  #   @return [::Boolean]
  #     Output only. If true, the tool does not modify its environment.
  #     Default: false
  class Annotations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. Human-readable name of the tool.

Returns:

  • (::String)

    Output only. Human-readable name of the tool.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 74

class Tool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Annotations describing the characteristics and behavior of a tool or
  # operation.
  # @!attribute [r] title
  #   @return [::String]
  #     Output only. A human-readable title for the tool.
  # @!attribute [r] destructive_hint
  #   @return [::Boolean]
  #     Output only. If true, the tool may perform destructive updates to its
  #     environment. If false, the tool performs only additive updates. NOTE:
  #     This property is meaningful only when `read_only_hint == false`
  #     Default: true
  # @!attribute [r] idempotent_hint
  #   @return [::Boolean]
  #     Output only. If true, calling the tool repeatedly with the same
  #     arguments will have no additional effect on its environment. NOTE: This
  #     property is meaningful only when `read_only_hint == false` Default:
  #     false
  # @!attribute [r] open_world_hint
  #   @return [::Boolean]
  #     Output only. If true, this tool may interact with an "open world" of
  #     external entities. If false, the tool's domain of interaction is
  #     closed. For example, the world of a web search tool is open, whereas
  #     that of a memory tool is not. Default: true
  # @!attribute [r] read_only_hint
  #   @return [::Boolean]
  #     Output only. If true, the tool does not modify its environment.
  #     Default: false
  class Annotations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end