Class: Google::Cloud::AgentRegistry::V1::SearchAgentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb

Overview

Message for response to searching Agents

Instance Attribute Summary collapse

Instance Attribute Details

#agents::Array<::Google::Cloud::AgentRegistry::V1::Agent>

Returns A list of Agents that match the search_string.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 129

class SearchAgentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns If there are more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token.

Returns:

  • (::String)

    If there are more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token.



129
130
131
132
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 129

class SearchAgentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end