Class: Google::Cloud::AgentRegistry::V1::SearchMcpServersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb

Overview

Message for searching MCP Servers

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of search results to return per page. The page size is capped at 100, even if a larger value is specified. A negative value will result in an INVALID_ARGUMENT error. If unspecified or set to 0, a default value of 20 will be used. The server may return fewer results than requested.

Returns:

  • (::Integer)

    Optional. The maximum number of search results to return per page. The page size is capped at 100, even if a larger value is specified. A negative value will result in an INVALID_ARGUMENT error. If unspecified or set to 0, a default value of 20 will be used. The server may return fewer results than requested.



290
291
292
293
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 290

class SearchMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. If present, retrieve the next batch of results from the preceding call to this method. page_token must be the value of next_page_token from the previous response. The values of all other method parameters, must be identical to those in the previous call.

Returns:

  • (::String)

    Optional. If present, retrieve the next batch of results from the preceding call to this method. page_token must be the value of next_page_token from the previous response. The values of all other method parameters, must be identical to those in the previous call.



290
291
292
293
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 290

class SearchMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent value for SearchMcpServersRequest. Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. Parent value for SearchMcpServersRequest. Format: projects/{project}/locations/{location}.



290
291
292
293
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 290

class SearchMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#search_string::String

Optional. Search criteria used to select the MCP Servers to return. If no search criteria is specified then all accessible MCP Servers will be returned.

Search expressions can be used to restrict results based upon searchable fields, where the operators can be used along with the suffix wildcard symbol *. See instructions for more details.

Allowed operators: =, :, NOT, AND, OR, and ().

Searchable fields:

Field = : * Keyword Search
mcpServerId Yes Yes Yes Included
name No Yes Yes Included
displayName No Yes Yes Included

Examples:

  • mcpServerId="urn:mcp:projects-123:projects:123:locations:us-central1:agentregistry:services:service-id" to find the MCP Server with the specified MCP Server ID.
  • name:important to find MCP Servers whose name contains important as a word.
  • displayName:works* to find MCP Servers whose display name contains words that start with works.
  • planner OR booking to find MCP Servers whose metadata contains the words planner or booking.
  • mcpServerId:service-id AND (displayName:planner OR displayName:booking) to find MCP Servers whose MCP Server ID contains service-id and whose display name contains planner or booking.

Returns:

  • (::String)

    Optional. Search criteria used to select the MCP Servers to return. If no search criteria is specified then all accessible MCP Servers will be returned.

    Search expressions can be used to restrict results based upon searchable fields, where the operators can be used along with the suffix wildcard symbol *. See instructions for more details.

    Allowed operators: =, :, NOT, AND, OR, and ().

    Searchable fields:

    Field = : * Keyword Search
    mcpServerId Yes Yes Yes Included
    name No Yes Yes Included
    displayName No Yes Yes Included

    Examples:

    • mcpServerId="urn:mcp:projects-123:projects:123:locations:us-central1:agentregistry:services:service-id" to find the MCP Server with the specified MCP Server ID.
    • name:important to find MCP Servers whose name contains important as a word.
    • displayName:works* to find MCP Servers whose display name contains words that start with works.
    • planner OR booking to find MCP Servers whose metadata contains the words planner or booking.
    • mcpServerId:service-id AND (displayName:planner OR displayName:booking) to find MCP Servers whose MCP Server ID contains service-id and whose display name contains planner or booking.


290
291
292
293
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 290

class SearchMcpServersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end