Class: Google::Cloud::AgentRegistry::V1::SearchMcpServersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::SearchMcpServersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for response to searching MCP Servers
Instance Attribute Summary collapse
-
#mcp_servers ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::McpServer>
A list of McpServers that match the
search_string. -
#next_page_token ⇒ ::String
If there are more results than those appearing in this response, then
next_page_tokenis included.
Instance Attribute Details
#mcp_servers ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::McpServer>
Returns A list of McpServers that match the search_string.
304 305 306 307 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 304 class SearchMcpServersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns If there are more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
304 305 306 307 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 304 class SearchMcpServersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |