Class: Google::Cloud::AgentRegistry::V1::Service::AgentSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/service.rb

Overview

The spec of the agent.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#content::Google::Protobuf::Struct

Returns Optional. The content of the Agent spec in the JSON format. This payload is validated against the schema for the specified type. The content size is limited to 10KB.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. The content of the Agent spec in the JSON format. This payload is validated against the schema for the specified type. The content size is limited to 10KB.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 85

class AgentSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the agent spec.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # There is no spec for the Agent. The `content` field must be empty.
    NO_SPEC = 1

    # The content is an A2A Agent Card following the A2A specification.
    # The `interfaces` field must be empty.
    A2A_AGENT_CARD = 2
  end
end

#type::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type

Returns Required. The type of the agent spec content.

Returns:



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 85

class AgentSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the agent spec.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # There is no spec for the Agent. The `content` field must be empty.
    NO_SPEC = 1

    # The content is an A2A Agent Card following the A2A specification.
    # The `interfaces` field must be empty.
    A2A_AGENT_CARD = 2
  end
end