Class: Google::Cloud::AgentRegistry::V1::Service::McpServerSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/agentregistry/v1/service.rb

Overview

The spec of the MCP Server.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#content::Google::Protobuf::Struct

Returns Optional. The content of the MCP Server spec. This payload is validated against the schema for the specified type. The content size is limited to 10KB.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. The content of the MCP Server spec. This payload is validated against the schema for the specified type. The content size is limited to 10KB.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 112

class McpServerSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the MCP Server spec.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # There is no spec for the MCP Server. The `content` field must be empty.
    NO_SPEC = 1

    # The content is a MCP Tool Spec following the One MCP specification.
    # The payload is the same as the `tools/list` response.
    TOOL_SPEC = 2
  end
end

#type::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type

Returns Required. The type of the MCP Server spec content.

Returns:



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 112

class McpServerSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the MCP Server spec.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # There is no spec for the MCP Server. The `content` field must be empty.
    NO_SPEC = 1

    # The content is a MCP Tool Spec following the One MCP specification.
    # The payload is the same as the `tools/list` response.
    TOOL_SPEC = 2
  end
end