Class: Google::Cloud::AgentRegistry::V1::CreateBindingRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::CreateBindingRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for creating a Binding
Instance Attribute Summary collapse
-
#binding ⇒ ::Google::Cloud::AgentRegistry::V1::Binding
Required.
-
#binding_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#binding ⇒ ::Google::Cloud::AgentRegistry::V1::Binding
Returns Required. The Binding resource that is being created.
627 628 629 630 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 627 class CreateBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#binding_id ⇒ ::String
Returns Required. The ID to use for the binding, which will become the final component of the binding's resource name.
This value should be 4-63 characters, and must conform to RFC-1034.
Specifically, it must match the regular expression
^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$.
627 628 629 630 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 627 class CreateBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location to create the Binding in.
Expected format: projects/{project}/locations/{location}.
627 628 629 630 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 627 class CreateBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
627 628 629 630 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 627 class CreateBindingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |