Class: Google::Cloud::AgentRegistry::V1::ListBindingsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::ListBindingsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for requesting a list of Bindings.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A query string used to filter the list of bindings returned. The filter expression must follow AIP-160 syntax.
565 566 567 568 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 565 class ListBindingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Hint for how to order the results.
565 566 567 568 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 565 class ListBindingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than
requested. Page size is 500 if unspecified and is capped at 500 even if a
larger value is given.
565 566 567 568 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 565 class ListBindingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
565 566 567 568 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 565 class ListBindingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location to list bindings in.
Expected format: projects/{project}/locations/{location}.
565 566 567 568 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 565 class ListBindingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |