Class: Google::Cloud::AgentRegistry::V1::McpServer::Tool::Annotations
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::McpServer::Tool::Annotations
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/mcp_server.rb
Overview
Annotations describing the characteristics and behavior of a tool or operation.
Instance Attribute Summary collapse
-
#destructive_hint ⇒ ::Boolean
readonly
Output only.
-
#idempotent_hint ⇒ ::Boolean
readonly
Output only.
-
#open_world_hint ⇒ ::Boolean
readonly
Output only.
-
#read_only_hint ⇒ ::Boolean
readonly
Output only.
-
#title ⇒ ::String
readonly
Output only.
Instance Attribute Details
#destructive_hint ⇒ ::Boolean (readonly)
Returns Output only. If true, the tool may perform destructive updates to its
environment. If false, the tool performs only additive updates. NOTE:
This property is meaningful only when read_only_hint == false
Default: true.
105 106 107 108 |
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 105 class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#idempotent_hint ⇒ ::Boolean (readonly)
Returns Output only. If true, calling the tool repeatedly with the same
arguments will have no additional effect on its environment. NOTE: This
property is meaningful only when read_only_hint == false Default:
false.
105 106 107 108 |
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 105 class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#open_world_hint ⇒ ::Boolean (readonly)
Returns Output only. If true, this tool may interact with an "open world" of external entities. If false, the tool's domain of interaction is closed. For example, the world of a web search tool is open, whereas that of a memory tool is not. Default: true.
105 106 107 108 |
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 105 class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read_only_hint ⇒ ::Boolean (readonly)
Returns Output only. If true, the tool does not modify its environment. Default: false.
105 106 107 108 |
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 105 class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String (readonly)
Returns Output only. A human-readable title for the tool.
105 106 107 108 |
# File 'proto_docs/google/cloud/agentregistry/v1/mcp_server.rb', line 105 class Annotations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |