Class: Google::Cloud::AgentRegistry::V1::SearchAgentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::SearchAgentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for searching Agents
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#search_string ⇒ ::String
Optional.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of search results to return per page. The page
size is capped at 100, even if a larger value is specified. A negative
value will result in an INVALID_ARGUMENT error. If unspecified or set to
0, a default value of 20 will be used. The server may return fewer
results than requested.
115 116 117 118 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 115 class SearchAgentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. If present, retrieve the next batch of results from the preceding
call to this method. page_token must be the value of next_page_token
from the previous response. The values of all other method parameters, must
be identical to those in the previous call.
115 116 117 118 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 115 class SearchAgentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent value for SearchAgentsRequest. Format:
projects/{project}/locations/{location}.
115 116 117 118 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 115 class SearchAgentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#search_string ⇒ ::String
Returns Optional. Search criteria used to select the Agents to return. If no search criteria is specified then all accessible Agents will be returned.
Search expressions can be used to restrict results based upon searchable
fields, where the operators can be used along with the suffix wildcard
symbol *. See
instructions
for more details.
Allowed operators: =, :, NOT, AND, OR, and ().
Searchable fields:
| Field | = |
: |
* |
Keyword Search |
|---|---|---|---|---|
| agentId | Yes | Yes | Yes | Included |
| name | No | Yes | Yes | Included |
| displayName | No | Yes | Yes | Included |
| description | No | Yes | No | Included |
| skills | No | Yes | No | Included |
| skills.id | No | Yes | No | Included |
| skills.name | No | Yes | No | Included |
| skills.description | No | Yes | No | Included |
| skills.tags | No | Yes | No | Included |
| skills.examples | No | Yes | No | Included |
Examples:
agentId="urn:agent:projects-123:projects:123:locations:us-central1:reasoningEngines:1234"to find the agent with the specified agent ID.name:importantto find agents whose name containsimportantas a word.displayName:works*to find agents whose display name contains words that start withworks.skills.tags:testto find agents whose skills tags containtest.planner OR bookingto find agents whose metadata contains the wordsplannerorbooking.
115 116 117 118 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 115 class SearchAgentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |