Class: Google::Cloud::AgentRegistry::V1::SearchAgentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::SearchAgentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb
Overview
Message for response to searching Agents
Instance Attribute Summary collapse
-
#agents ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Agent>
A list of Agents that match the
search_string. -
#next_page_token ⇒ ::String
If there are more results than those appearing in this response, then
next_page_tokenis included.
Instance Attribute Details
#agents ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Agent>
Returns A list of Agents that match the search_string.
129 130 131 132 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 129 class SearchAgentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns If there are more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token.
129 130 131 132 |
# File 'proto_docs/google/cloud/agentregistry/v1/agentregistry_service.rb', line 129 class SearchAgentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |