Class: Google::Cloud::AgentRegistry::V1::Service
- Inherits:
-
Object
- Object
- Google::Cloud::AgentRegistry::V1::Service
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/agentregistry/v1/service.rb
Overview
Represents a user-defined Service.
Defined Under Namespace
Classes: AgentSpec, EndpointSpec, McpServerSpec
Instance Attribute Summary collapse
-
#agent_spec ⇒ ::Google::Cloud::AgentRegistry::V1::Service::AgentSpec
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Optional.
-
#endpoint_spec ⇒ ::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec
Optional.
-
#interfaces ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Interface>
Optional.
-
#mcp_server_spec ⇒ ::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec
Optional.
-
#name ⇒ ::String
Identifier.
-
#registry_resource ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#agent_spec ⇒ ::Google::Cloud::AgentRegistry::V1::Service::AgentSpec
Returns Optional. The spec of the Agent. When agent_spec is set, the type of
the service is Agent.
Note: The following fields are mutually exclusive: agent_spec, mcp_server_spec, endpoint_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#description ⇒ ::String
Returns Optional. User-defined description of an Service.
Can have a maximum length of 2048 characters.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#display_name ⇒ ::String
Returns Optional. User-defined display name for the Service.
Can have a maximum length of 63 characters.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#endpoint_spec ⇒ ::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec
Returns Optional. The spec of the Endpoint. When endpoint_spec is set, the type
of the service is Endpoint.
Note: The following fields are mutually exclusive: endpoint_spec, agent_spec, mcp_server_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#interfaces ⇒ ::Array<::Google::Cloud::AgentRegistry::V1::Interface>
Returns Optional. The connection details for the Service.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#mcp_server_spec ⇒ ::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec
Returns Optional. The spec of the MCP Server. When mcp_server_spec is set, the
type of the service is MCP Server.
Note: The following fields are mutually exclusive: mcp_server_spec, agent_spec, endpoint_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#name ⇒ ::String
Returns Identifier. The resource name of the Service.
Format: projects/{project}/locations/{location}/services/{service}.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#registry_resource ⇒ ::String (readonly)
Returns Output only. The resource name of the resulting Agent, MCP Server, or Endpoint. Format:
projects/{project}/locations/{location}/mcpServers/{mcp_server}projects/{project}/locations/{location}/agents/{agent}projects/{project}/locations/{location}/endpoints/{endpoint}.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Update time.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'proto_docs/google/cloud/agentregistry/v1/service.rb', line 72 class Service include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The spec of the agent. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::AgentSpec::Type] # Required. The type of the agent spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the Agent spec in the JSON format. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class AgentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the agent spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Agent. The `content` field must be empty. NO_SPEC = 1 # The content is an A2A Agent Card following the A2A specification. # The `interfaces` field must be empty. A2A_AGENT_CARD = 2 end end # The spec of the MCP Server. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::McpServerSpec::Type] # Required. The type of the MCP Server spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the MCP Server spec. # This payload is validated against the schema for the specified type. # The content size is limited to `10KB`. class McpServerSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the MCP Server spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the MCP Server. The `content` field must be empty. NO_SPEC = 1 # The content is a MCP Tool Spec following the One MCP specification. # The payload is the same as the `tools/list` response. TOOL_SPEC = 2 end end # The spec of the endpoint. # @!attribute [rw] type # @return [::Google::Cloud::AgentRegistry::V1::Service::EndpointSpec::Type] # Required. The type of the endpoint spec content. # @!attribute [rw] content # @return [::Google::Protobuf::Struct] # Optional. The content of the endpoint spec. # Reserved for future use. class EndpointSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the endpoint spec. module Type # Unspecified type. TYPE_UNSPECIFIED = 0 # There is no spec for the Endpoint. The `content` field must be empty. NO_SPEC = 1 end end end |